from setuptools import setup

setup(
    name='messengerpy',
    version='0.0.1',
    description='',
    long_description='Facebook Messenger API',
    author='',
    url='',
    packages=['messengerpy'],
)
